@@ -2,6 +2,9 @@
 #include <QNetworkAccessManager>
 #include <QNetworkRequest>
 #include <QNetworkReply>
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 MegaShares::MegaShares(QObject *parent) :
     RecaptchaPlugin(parent)
@@ -9,17 +12,25 @@ MegaShares::MegaShares(QObject *parent) :
 }
 
 void MegaShares::getCaptcha(const QString &key) {
-    m_challenge = key;
-    QUrl url("http://d01.megashares.comindex.php?secgfx=gfx");
+    this->setChallenge(key);
+    QUrl url("http://d01.megashares.comindex.php");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("secgfx", "gfx");
+    query.addQueryItem("random_num", key);
+    url.setQuery(query);
+#else
     url.addQueryItem("secgfx", "gfx");
     url.addQueryItem("random_num", key);
+#endif
     QNetworkRequest request(url);
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(onCaptchaDownloaded()));
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
 }
 
 void MegaShares::onCaptchaDownloaded() {
-    QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply *reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error(NetworkError);
@@ -29,7 +40,7 @@ void MegaShares::onCaptchaDownloaded() {
     int statusCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
 
     if (statusCode == 200) {
-        emit gotCaptcha(reply->readAll());
+        emit captchaReady(reply->readAll());
     }
     else {
         this->reportError(statusCode);
@@ -57,4 +68,10 @@ void MegaShares::reportError(int errorCode) {
     }
 }
 
+bool MegaShares::cancelCurrentOperation() {
+    emit currentOperationCancelled();
+
+    return true;
+}
+
 Q_EXPORT_PLUGIN2(megasharesrecaptcha, MegaShares)
