@@ -17,12 +17,16 @@ public:
     inline RecaptchaPlugin* createRecaptchaPlugin() { return new MegaShares; }
     inline QString serviceName() const { return QString("MegaShares"); }
     void getCaptcha(const QString &key);
+    bool cancelCurrentOperation();
 
 private:
     void reportError(int errorCode);
 
 private slots:
     void onCaptchaDownloaded();
+
+signals:
+    void currentOperationCancelled();
 };
 
 #endif // MEGASHARES_H
